# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb.tools
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XTableName(ABC):
    """
    allows to manipulate table names.
    
    When, in a database application, dealing with table names, there's many degrees of freedom to deal with. For instance, suppose you want to have the full name of a table object, as it should be used in a SELECT statement's FROM part. This requires you to evaluate whether or not the table has a catalog and/or schema name, to combine the catalog, the schema, and the basic table name into one name, respecting the database's quoting character, and the order in which all those parts should be combined. Additionally, you have to respect the client-side settings which tell OpenOffice.org to use or not use catalogs and schemas in SELECT at all.
    
    The XTableName interface eases this and other, similar tasks around table names.
    
    The component itself does not have life-time control mechanisms, i.e. you cannot explicitly dispose it (com.sun.star.lang.XComponent.dispose()), and you cannot be notified when it dies.
    However, if your try to access any of its methods or attributes, after the connection which was used to create it was closed, a com.sun.star.lang.DisposedException will be thrown.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XTableName <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableName.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.tools.XTableName']

    def getComposedName(self, Type: int, Quote: bool) -> str:
        """
        returns the composed table name, including the catalog and schema name, respecting the database's quoting requirements, plus

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setComposedName(self, ComposedName: str, Type: int) -> None:
        """
        sets a new composed table name
        """
    @property
    def CatalogName(self) -> str:
        """
        denotes the name of the catalog which the table is a part of
        """

    @property
    def NameForSelect(self) -> str:
        """
        represents the table name in a form to be used in a SELECT statement.
        
        On a per-data-source basis, OpenOffice.org allows to override database meta data information in that you can specify to not use catalog and or schema names in SELECT statements. Using this attribute, you can generate a table name which respects those settings.
        """

    @property
    def SchemaName(self) -> str:
        """
        denotes the name of the schema which the table is a part of
        """

    @property
    def Table(self) -> 'XPropertySet_bc180bfa':
        """
        is the com.sun.star.sdb.Table object specified by the current name.
        
        Retrieving this attribute is equivalent to obtaining the tables container from the connection (via com.sun.star.sdbcx.XTablesSupplier), and calling its com.sun.star.container.XNameAccess.getByName() method with the ComposedName.
        """

    @property
    def TableName(self) -> str:
        """
        denotes the mere, unqualified table name, excluding any catalog and schema.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

Constants of bit masks used with XFormulaOpCodeMapper.getAvailableMappings() to specify for which group of symbols the mappings are to be obtained.

If no bit is set, a sequence of special mappings is returned in the order that is defined by FormulaMapGroupSpecialOffset. Note that the special group and other groups are mutual exclusive.

See Also:
    `API FormulaMapGroup <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html>`_
"""
SPECIAL: Literal[0]
"""
Group of op-codes without a string symbol.
"""
SEPARATORS: Literal[1]
"""
Separators and parentheses.
"""
ARRAY_SEPARATORS: Literal[2]
"""
Separators and parentheses for constant arrays.
"""
UNARY_OPERATORS: Literal[4]
"""
Unary operators.
"""
BINARY_OPERATORS: Literal[8]
"""
Binary operators.
"""
FUNCTIONS: Literal[16]
"""
Functions.
"""
ALL_EXCEPT_SPECIAL: Literal[2147483647]
"""
All groups except SPECIAL.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from .x_persistent_library_container import XPersistentLibraryContainer as XPersistentLibraryContainer_b6b2129e
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32

class XStorageBasedLibraryContainer(XPersistentLibraryContainer_b6b2129e):
    """
    is the interface for an XLibraryContainer which can be made persistent in a com.sun.star.embed.XStorage.
    
    A persistent library container is associated with a root storage. The container is responsible for a particular sub storage of the root storage, the container storage.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XStorageBasedLibraryContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XStorageBasedLibraryContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XStorageBasedLibraryContainer']

    def storeLibrariesToStorage(self, RootStorage: 'XStorage_8e460a32') -> None:
        """
        stores the libraries to a storage other than the current container storage
        
        Note that the library container is not automatically associated with the new root storage. Instead, you need to manually set the RootStorage attribute afterwards. This separation allows for Save-To as well Save-As operations.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    @property
    def RootStorage(self) -> 'XStorage_8e460a32':
        """
        denotes the root storage associated with the container.
        
        Effectively, this attribute is a typed version of XPersistentLibraryContainer.RootLocation, it's guaranteed that at every time, XPersistentLibraryContainer.RootLocation and RootStorage have the same value.
        
        You should only set this attribute to a new value if you previously called storeLibrariesToStorage with the same storage. Setting this attribute to a storage into which the container has not been stored previously might result in unexpected behavior.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.lang
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection_point import XConnectionPoint as XConnectionPoint_e0da0d1c

class XConnectionPointContainer(XInterface_8f010a43):
    """
    makes it possible to locate a specific connection point for a specified UIK and manages a sequence of connections points.
    
    An implementation of this interface must support the com.sun.star.uno.XWeak interface. Look at the language binding for a superclass or something else.

    See Also:
        `API XConnectionPointContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPointContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.lang.XConnectionPointContainer']

    def advise(self, aType: object, xListener: 'XInterface_8f010a43') -> None:
        """
        creates a connection between this object and a client's sink, where the sink implements the outgoing interface specified with ID.
        
        The interface is advised under the connection point you get with queryConnectionPoint( id ).
        
        Use this method instead of the advise method at the connection point, only if you know that the broadcaster supports the outgoing interface, or if it does not matter that the outgoing interface is not supported.
        """
    def getConnectionPointTypes(self) -> 'typing.Tuple[object, ...]':
        """
        """
    def queryConnectionPoint(self, aType: object) -> 'XConnectionPoint_e0da0d1c':
        """
        """
    def unadvise(self, aType: object, xListener: 'XInterface_8f010a43') -> None:
        """
        terminates a notification previously set up with advise at the container or at the suitable connection point.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from ..document.header_footer_settings import HeaderFooterSettings as HeaderFooterSettings_5acd1070
from ..document.settings import Settings as Settings_b2bc0bb8

class DocumentSettings(HeaderFooterSettings_5acd1070, Settings_b2bc0bb8):
    """
    Service Class

    describes properties that apply to the whole drawing document.

    See Also:
        `API DocumentSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1DocumentSettings.html>`_
    """
    @property
    def IsPrintFitPage(self) -> bool:
        """
        enables or disables the fitting of the page to the printable area during print
        """
    @property
    def IsPrintTilePage(self) -> bool:
        """
        if this is true and the paper size for printing is larger than the paper size of the printer than the content is tiled over multiple pages.
        """
    @property
    def MeasureUnit(self) -> int:
        """
        This is the default logical measure unit that is used for string formatting inside the document, f.e.
        
        the measure text
        """
    @property
    def PageNumberFormat(self) -> int:
        """
        is the number format used for page number fields
        
        Values 0-7 are supported.
        """
    @property
    def ParagraphSummation(self) -> bool:
        """
        If this is true, the distance between two paragraphs is the sum of ParaBottomMargin of the previous and ParaTopMargin of the next paragraph.
        
        If false, only the greater of the two is chosen.
        """
    @property
    def ScaleDenominator(self) -> int:
        """
        is the denominator for the logical scale of the document
        """
    @property
    def ScaleNumerator(self) -> int:
        """
        is the numerator for the logical scale of the document
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.gallery
from typing_extensions import Literal
import typing
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XGalleryTheme(XIndexAccess_f0910d6d):
    """
    provides access to the items of a Gallery themes.
    
    It also allows inserting and removing of single items.
    
    This interface extends the interface com.sun.star.container.XIndexAccess which provides access to existing Gallery items collection.

    See Also:
        `API XGalleryTheme <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1gallery_1_1XGalleryTheme.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.gallery.XGalleryTheme']

    def getName(self) -> str:
        """
        retrieves the name of the Gallery theme
        """
    def insertDrawingByIndex(self, Drawing: 'XComponent_98dc0ab5', Index: int) -> int:
        """
        inserts an item

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def insertGraphicByIndex(self, Graphic: 'XGraphic_a4da0afc', Index: int) -> int:
        """
        inserts an item

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def insertURLByIndex(self, URL: str, Index: int) -> int:
        """
        inserts an item

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeByIndex(self, Index: int) -> None:
        """
        deletes an item from the collection

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def update(self) -> None:
        """
        updates the theme
        
        This method iterates over each item of the Gallery theme and updates it accordingly. Main purpose is to automatically regenerate the thumbnails and to remove invalid items, that is items who have got a URL that has become invalid. This method also optimizes underlying data structures.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.form.component.check_box import CheckBox as CheckBox
from ..._pyi.form.component.combo_box import ComboBox as ComboBox
from ..._pyi.form.component.command_button import CommandButton as CommandButton
from ..._pyi.form.component.currency_field import CurrencyField as CurrencyField
from ..._pyi.form.component.data_form import DataForm as DataForm
from ..._pyi.form.component.database_check_box import DatabaseCheckBox as DatabaseCheckBox
from ..._pyi.form.component.database_combo_box import DatabaseComboBox as DatabaseComboBox
from ..._pyi.form.component.database_currency_field import DatabaseCurrencyField as DatabaseCurrencyField
from ..._pyi.form.component.database_date_field import DatabaseDateField as DatabaseDateField
from ..._pyi.form.component.database_formatted_field import DatabaseFormattedField as DatabaseFormattedField
from ..._pyi.form.component.database_image_control import DatabaseImageControl as DatabaseImageControl
from ..._pyi.form.component.database_list_box import DatabaseListBox as DatabaseListBox
from ..._pyi.form.component.database_numeric_field import DatabaseNumericField as DatabaseNumericField
from ..._pyi.form.component.database_pattern_field import DatabasePatternField as DatabasePatternField
from ..._pyi.form.component.database_radio_button import DatabaseRadioButton as DatabaseRadioButton
from ..._pyi.form.component.database_text_field import DatabaseTextField as DatabaseTextField
from ..._pyi.form.component.database_time_field import DatabaseTimeField as DatabaseTimeField
from ..._pyi.form.component.date_field import DateField as DateField
from ..._pyi.form.component.file_control import FileControl as FileControl
from ..._pyi.form.component.fixed_text import FixedText as FixedText
from ..._pyi.form.component.form import Form as Form
from ..._pyi.form.component.formatted_field import FormattedField as FormattedField
from ..._pyi.form.component.grid_control import GridControl as GridControl
from ..._pyi.form.component.group_box import GroupBox as GroupBox
from ..._pyi.form.component.html_form import HTMLForm as HTMLForm
from ..._pyi.form.component.hidden_control import HiddenControl as HiddenControl
from ..._pyi.form.component.image_button import ImageButton as ImageButton
from ..._pyi.form.component.list_box import ListBox as ListBox
from ..._pyi.form.component.navigation_tool_bar import NavigationToolBar as NavigationToolBar
from ..._pyi.form.component.numeric_field import NumericField as NumericField
from ..._pyi.form.component.pattern_field import PatternField as PatternField
from ..._pyi.form.component.radio_button import RadioButton as RadioButton
from ..._pyi.form.component.rich_text_control import RichTextControl as RichTextControl
from ..._pyi.form.component.scroll_bar import ScrollBar as ScrollBar
from ..._pyi.form.component.spin_button import SpinButton as SpinButton
from ..._pyi.form.component.submit_button import SubmitButton as SubmitButton
from ..._pyi.form.component.text_field import TextField as TextField
from ..._pyi.form.component.time_field import TimeField as TimeField



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_regression_curve import XRegressionCurve as XRegressionCurve_fa3c0dca

class XRegressionCurveContainer(XInterface_8f010a43):
    """

    See Also:
        `API XRegressionCurveContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XRegressionCurveContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XRegressionCurveContainer']

    def addRegressionCurve(self, aRegressionCurve: 'XRegressionCurve_fa3c0dca') -> None:
        """
        add a regression curve to the container

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getRegressionCurves(self) -> 'typing.Tuple[XRegressionCurve_fa3c0dca, ...]':
        """
        retrieve all regression curves
        """
    def removeRegressionCurve(self, aRegressionCurve: 'XRegressionCurve_fa3c0dca') -> None:
        """
        removes one regression curve from the container.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def setRegressionCurves(self, aRegressionCurves: 'typing.Tuple[XRegressionCurve_fa3c0dca, ...]') -> None:
        """
        set all regression curves

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.key_event import KeyEvent as KeyEvent_7a78097f
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.size import Size as Size_576707ef
    from ..frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
    from ..frame.x_layout_manager import XLayoutManager as XLayoutManager_d4510ca4

class XInplaceClient(XInterface_8f010a43):
    """
    represents common functionality for inplace clients.

    See Also:
        `API XInplaceClient <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XInplaceClient']

    def activatingInplace(self) -> None:
        """
        notifies container through the client that the object is to be inplace activated.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def activatingUI(self) -> None:
        """
        notifies container through the client that the object is to be UI-activated.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def canInplaceActivate(self) -> bool:
        """
        checks if the container can activate the object inplace.
        """
    def changedPlacement(self, aPosRect: 'Rectangle_84b109e9') -> None:
        """
        notifies the container that the position of the object is changed.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
    def deactivatedInplace(self) -> None:
        """
        notifies container through the client that the object is deactivated.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def deactivatedUI(self) -> None:
        """
        notifies container through the client that the object is UI-deactivated.
        
        After this notification the container can restore its own UI and take focus.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def getClipRectangle(self) -> 'Rectangle_84b109e9':
        """
        gets the inplace object clip rectangle.
        
        The rectangle is provided in object's parent window coordinates in pixels. The intersection of position and clip rectangles specifies the visible part of the object.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def getInplaceDispatchProvider(self) -> 'XDispatchProvider_fc690de6':
        """
        allows to retrieve the container's dispatch provider.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def getLayoutManager(self) -> 'XLayoutManager_d4510ca4':
        """
        allows to retrieve the com.sun.star.frame.LayoutManager of the container.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def getPlacement(self) -> 'Rectangle_84b109e9':
        """
        gets the inplace object position rectangle.
        
        The rectangle is provided in object's parent window coordinates in pixels. The intersection of position and clip rectangles specifies the visible part of the object. In case the position window has a size that is bigger than object's size, the object should either scale or deactivate.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def scrollObject(self, aOffset: 'Size_576707ef') -> None:
        """
        scrolls the object.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
    def translateAccelerators(self, aKeys: 'typing.Tuple[KeyEvent_7a78097f, ...]') -> None:
        """
        provides accelerator table the object wants to use while it is inplace active.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.media
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class XFrameGrabber(ABC):
    """
    This interface provides an easy access to a stream images using their position in the time.

    See Also:
        `API XFrameGrabber <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1media_1_1XFrameGrabber.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.media.XFrameGrabber']

    def grabFrame(self, fMediaTime: float) -> 'XGraphic_a4da0afc':
        """
        returns the image of the underlying stream at a given position
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.deployment
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..xml.dom.x_element import XElement as XElement_a33d0ae9


class UpdateInformationEntry(object):
    """
    Struct Class

    Objects of this type are used as elements of the enumeration returned by XUpdateInformationProvider.
    
    **since**
    
        OOo 2.3

    See Also:
        `API UpdateInformationEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1deployment_1_1UpdateInformationEntry.html>`_
    """
    typeName: Literal['com.sun.star.deployment.UpdateInformationEntry']

    def __init__(self, UpdateDocument: typing.Optional[XElement_a33d0ae9] = ..., Description: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            UpdateDocument (XElement, optional): UpdateDocument value.
            Description (str, optional): Description value.
        """


    @property
    def UpdateDocument(self) -> XElement_a33d0ae9:
        """
        the DOM representation of an update information entry
        """


    @property
    def Description(self) -> str:
        """
        the (optional) description for an update information entry extracted from the update feed container
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9

class XAudio(XAnimationNode_1cf10eb9):
    """
    
    **since**
    
        LibreOffice 7.2

    See Also:
        `API XAudio <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAudio.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XAudio']

    @property
    def HideDuringShow(self) -> bool:
        """
        Specifies if the source shape should be hidden during slideshow (defaults to false).
        
        **since**
        
            LibreOffice 7.2
        """

    @property
    def Narration(self) -> bool:
        """
        Specifies if the source shape is a narration for the slide (defaults to false).
        
        **since**
        
            LibreOffice 7.2
        """

    @property
    def Source(self) -> object:
        """
        This attribute specifies the source element that contains the audio.
        """

    @property
    def Volume(self) -> float:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_compound_type_description import XCompoundTypeDescription as XCompoundTypeDescription_c7be12f6
    from .x_parameter import XParameter as XParameter_e4470d2c

class XServiceConstructorDescription(ABC):
    """
    Reflects a service constructor.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XServiceConstructorDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XServiceConstructorDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XServiceConstructorDescription']

    def getExceptions(self) -> 'typing.Tuple[XCompoundTypeDescription_c7be12f6, ...]':
        """
        Returns the exceptions that can be raised by the constructor.
        """
    def getName(self) -> str:
        """
        Returns the constructor's name.
        """
    def getParameters(self) -> 'typing.Tuple[XParameter_e4470d2c, ...]':
        """
        Returns the constructor's parameters.
        """
    def isDefaultConstructor(self) -> bool:
        """
        Returns whether the constructor is a default constructor.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .property_state import PropertyState as PropertyState_c97b0c77


class GetPropertyTolerantResult(object):
    """
    Struct Class

    specifies information being retrieved about a single property.

    See Also:
        `API GetPropertyTolerantResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1GetPropertyTolerantResult.html>`_
    """
    typeName: Literal['com.sun.star.beans.GetPropertyTolerantResult']

    def __init__(self, Result: typing.Optional[int] = ..., State: typing.Optional[PropertyState_c97b0c77] = ..., Value: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Result (int, optional): Result value.
            State (PropertyState, optional): State value.
            Value (object, optional): Value value.
        """


    @property
    def Result(self) -> int:
        """
        specifies a success or error code for the retrieval operation.
        """


    @property
    def State(self) -> PropertyState_c97b0c77:
        """
        contains the state of the property.
        
        The value is undefined if Result is not com.sun.star.beans.TolerantPropertySetResultType.SUCCESS.
        """


    @property
    def Value(self) -> object:
        """
        contains the value of the property.
        
        The value is undefined if Result is not com.sun.star.beans.TolerantPropertySetResultType.SUCCESS.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal


class TransitionType(object):
    """
    Const


    See Also:
        `API TransitionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionType.html>`_
    """
    BARWIPE: Literal[1]
    BOXWIPE: Literal[2]
    FOURBOXWIPE: Literal[3]
    BARNDOORWIPE: Literal[4]
    DIAGONALWIPE: Literal[5]
    BOWTIEWIPE: Literal[6]
    MISCDIAGONALWIPE: Literal[7]
    VEEWIPE: Literal[8]
    BARNVEEWIPE: Literal[9]
    ZIGZAGWIPE: Literal[10]
    BARNZIGZAGWIPE: Literal[11]
    IRISWIPE: Literal[12]
    TRIANGLEWIPE: Literal[13]
    ARROWHEADWIPE: Literal[14]
    PENTAGONWIPE: Literal[15]
    HEXAGONWIPE: Literal[16]
    ELLIPSEWIPE: Literal[17]
    EYEWIPE: Literal[18]
    ROUNDRECTWIPE: Literal[19]
    STARWIPE: Literal[20]
    MISCSHAPEWIPE: Literal[21]
    CLOCKWIPE: Literal[22]
    PINWHEELWIPE: Literal[23]
    SINGLESWEEPWIPE: Literal[24]
    FANWIPE: Literal[25]
    DOUBLEFANWIPE: Literal[26]
    DOUBLESWEEPWIPE: Literal[27]
    SALOONDOORWIPE: Literal[28]
    WINDSHIELDWIPE: Literal[29]
    SNAKEWIPE: Literal[30]
    SPIRALWIPE: Literal[31]
    PARALLELSNAKESWIPE: Literal[32]
    BOXSNAKESWIPE: Literal[33]
    WATERFALLWIPE: Literal[34]
    PUSHWIPE: Literal[35]
    SLIDEWIPE: Literal[36]
    FADE: Literal[37]
    RANDOMBARWIPE: Literal[38]
    CHECKERBOARDWIPE: Literal[39]
    DISSOLVE: Literal[40]
    BLINDSWIPE: Literal[41]
    RANDOM: Literal[42]
    ZOOM: Literal[43]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_axis import XAxis as XAxis_71210907
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from .chart_axis_arrange_order_type import ChartAxisArrangeOrderType as ChartAxisArrangeOrderType_783b10ff
    from .chart_axis_label_position import ChartAxisLabelPosition as ChartAxisLabelPosition_463a0fd6
    from .chart_axis_mark_position import ChartAxisMarkPosition as ChartAxisMarkPosition_373b0f81
    from .chart_axis_position import ChartAxisPosition as ChartAxisPosition_fcaa0df6
    from .time_increment import TimeIncrement as TimeIncrement_c7e70c4e

class ChartAxis(LineProperties_f13f0da9, CharacterProperties_1d4f0ef3, UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa, XAxis_71210907):
    """
    Service Class

    Specifies the axes in a diagram.
    
    Note: The text properties correlate to all axis description elements, not to just a single text element.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartAxis <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartAxis.html>`_
    """
    @property
    def ArrangeOrder(self) -> 'ChartAxisArrangeOrderType_783b10ff':
        """
        The axis description may be arranged in a special order for a better placement.
        """
    @property
    def AutoMax(self) -> bool:
        """
        The maximum value of the axis scale is calculated by the chart if this property is TRUE.
        """
    @property
    def AutoMin(self) -> bool:
        """
        The minimum value of the axis scale is calculated by the chart if this property is TRUE.
        """
    @property
    def AutoOrigin(self) -> bool:
        """
        The origin is calculated by the chart if this property is TRUE.
        """
    @property
    def AutoStepHelp(self) -> bool:
        """
        The number of help intervals within a main interval is calculated by the chart if this property is TRUE.
        """
    @property
    def AutoStepMain(self) -> bool:
        """
        The distance between the main tick marks is calculated by the chart if this property is TRUE.
        """
    @property
    def AxisType(self) -> int:
        """
        determines which type of axis this is, e.g.
        
        a date-axis or a category-axis
        
        **since**
        
            OOo 3.4
        """
    @property
    def CrossoverPosition(self) -> 'ChartAxisPosition_fcaa0df6':
        """
        Determines where the axis crosses the other axis.
        """
    @property
    def CrossoverValue(self) -> float:
        """
        Determines the scale value on the other axis when CrossoverPosition is set to VALUE.
        """
    @property
    def DisplayLabels(self) -> bool:
        """
        Properties for axes labels:
        
        Determines whether to display text at the axis or not.
        """
    @property
    def GapWidth(self) -> int:
        """
        Specifies the width of the gaps between each set of data points in a bar chart.
        
        The value is given in percent of the width of a bar; the valid range is 0 to 600%.
        """
    @property
    def HelpMarks(self) -> int:
        """
        Determines the type of the help marks.
        """
    @property
    def LabelPosition(self) -> 'ChartAxisLabelPosition_463a0fd6':
        """
        Determines where the axis labels are placed.
        """
    @property
    def LinkNumberFormatToSource(self) -> bool:
        """
        determines whether to use the number format given by the container application, e.g.
        
        a spreadsheet document, or from the own property NumberFormat.
        """
    @property
    def Logarithmic(self) -> bool:
        """
        Determines if the axis is scaled logarithmically or not (linear).
        """
    @property
    def MarkPosition(self) -> 'ChartAxisMarkPosition_373b0f81':
        """
        Determines where the interval marks are placed.
        """
    @property
    def Marks(self) -> int:
        """
        Properties for interval marks:
        
        Determines the type of the marks.
        """
    @property
    def Max(self) -> float:
        """
        Properties for scaling:
        
        Contains the maximum value for the axis scale.
        """
    @property
    def Min(self) -> float:
        """
        Contains the minimum value for the axis scale.
        """
    @property
    def NumberFormat(self) -> int:
        """
        Contains the type id for the number formatter of the axis.
        """
    @property
    def Origin(self) -> float:
        """
        Indicates the reference value where bars or areas have their grounding.
        
        This property has only an effect when the used ODF file format does not allow for further axis positioning or the axis is a secondary y-axis.
        """
    @property
    def Overlap(self) -> int:
        """
        Properties related to bar charts:
        
        Determines the overlap of the bars in a bar-type chart.
        
        The value is given in percent of the width of the bars. The valid range is -100% to +100%. +100% means full overlap, -100% indicates a distance of one bar between 2 neighboring bars.
        """
    @property
    def ReverseDirection(self) -> bool:
        """
        Determines if the axis orientation is mathematical or reversed.
        """
    @property
    def StepHelp(self) -> float:
        """
        """
    @property
    def StepHelpCount(self) -> int:
        """
        Contains the number of help intervals within a main interval.
        
        E.g. a StepHelpCount of 5 divides the main interval into 5 pieces and thus produces 4 help tick marks.
        """
    @property
    def StepMain(self) -> float:
        """
        Contains the distance between the main tick marks.
        """
    @property
    def TextBreak(self) -> bool:
        """
        Determines if long text is broken into multiple lines.
        """
    @property
    def TextCanOverlap(self) -> bool:
        """
        Determines if certain labels are hidden, if they would otherwise overlap.
        
        In this case, the value of this property must be set to FALSE.
        """
    @property
    def TextRotation(self) -> int:
        """
        Determines the rotation of the text elements (axis description) in 100th degrees.
        """
    @property
    def TimeIncrement(self) -> 'TimeIncrement_c7e70c4e':
        """
        if the current axis is a date-axis the intervals are chosen as given with TimeIncrement
        
        **since**
        
            OOo 3.4
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class XProgressBar(XInterface_8f010a43):
    """
    gives access to the value and settings of a progress bar.

    See Also:
        `API XProgressBar <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XProgressBar.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XProgressBar']

    def getValue(self) -> int:
        """
        returns the current progress value of the progress bar.
        """
    def setBackgroundColor(self, Color: 'Color_68e908c5') -> None:
        """
        sets the background color (RGB) of the control.
        """
    def setForegroundColor(self, Color: 'Color_68e908c5') -> None:
        """
        sets the foreground color (RGB) of the control.
        """
    def setRange(self, Min: int, Max: int) -> None:
        """
        sets the minimum and the maximum progress value of the progress bar.
        
        If the minimum value is greater than the maximum value, the method exchanges the values automatically.
        """
    def setValue(self, Value: int) -> None:
        """
        sets the progress value of the progress bar.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .argb_color import ARGBColor as ARGBColor_c6ee0be1
    from .color_component import ColorComponent as ColorComponent_e4c0e78
    from .rgb_color import RGBColor as RGBColor_bbdf0ba0

class XColorSpace(ABC):
    """
    Information how to interpret certain color data.
    
    This interface encapsulates all information that is necessary to interpret color data, by defining a describing color space, like for example CMYK or sRGB. You can either convert between this and an arbitrary other color space, or into the standard RGB or ARGB formats (because those are so overwhelmingly common in computer graphics).
    
    All canvas interfaces standardize to sequences of IEEE doubles for color representation. As this is overly verbose when used for bitmap data, derived interfaces exist, e.g. XIntegerBitmapColorSpace, which use sequences of integers for color representation.

    See Also:
        `API XColorSpace <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XColorSpace.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XColorSpace']

    def convertColorSpace(self, deviceColor: 'typing.Tuple[ColorComponent_e4c0e78, ...]', targetColorSpace: 'XColorSpace') -> 'typing.Tuple[ColorComponent_e4c0e78, ...]':
        """
        Convert to color of another color space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertFromARGB(self, rgbColor: 'typing.Tuple[ARGBColor_c6ee0be1, ...]') -> 'typing.Tuple[ColorComponent_e4c0e78, ...]':
        """
        Convert sRGB color with linear alpha into this color space.
        
        If this color space does not convey alpha information, the specified alpha value is silently ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertFromPARGB(self, rgbColor: 'typing.Tuple[ARGBColor_c6ee0be1, ...]') -> 'typing.Tuple[ColorComponent_e4c0e78, ...]':
        """
        Convert premultiplied sRGB color with linear alpha into this color space.
        
        If this color space does not convey alpha information, the specified alpha value is silently ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertFromRGB(self, rgbColor: 'typing.Tuple[RGBColor_bbdf0ba0, ...]') -> 'typing.Tuple[ColorComponent_e4c0e78, ...]':
        """
        Convert sRGB color to a representation in this color space.
        
        If this color space conveys alpha information, it is assumed be fully opaque for the given RGB color value.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertToARGB(self, deviceColor: 'typing.Tuple[ColorComponent_e4c0e78, ...]') -> 'typing.Tuple[ARGBColor_c6ee0be1, ...]':
        """
        Convert color value in this color space to sRGB color values, with linear alpha.
        
        If the given input color does not carry alpha information, an alpha value of 1.0 (fully opaque) is assumed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertToPARGB(self, deviceColor: 'typing.Tuple[ColorComponent_e4c0e78, ...]') -> 'typing.Tuple[ARGBColor_c6ee0be1, ...]':
        """
        Convert color value in this color space to premultiplied sRGB color values, with linear alpha.
        
        If the given input color does not carry alpha information, an alpha value of 1.0 (fully opaque) is assumed. The resulting individual RGB color values are premultiplied by the alpha value (e.g. if alpha is 0.5, each color value has only half of the original intensity).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def convertToRGB(self, deviceColor: 'typing.Tuple[ColorComponent_e4c0e78, ...]') -> 'typing.Tuple[RGBColor_bbdf0ba0, ...]':
        """
        Convert color value in this color space to sRGB color values.
        
        Any information not representable in the RGBColor struct is discarded during the conversion. This includes alpha information.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getComponentTags(self) -> 'typing.Tuple[int, ...]':
        """
        Query the kind for each color component.
        
        Color space components tend to correspond to physical attributes like the amount of one specific colorant contained in the final output color. This method returns a sequence of tags, specifying for each component of a color value, to what color attribute (if any) it corresponds. The values must be one of the ColorComponentTag constants.
        
        At the same time, the number of elements in this sequence corresponds to the number of color channels for this color space.
        """
    def getProperties(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Query various optional properties from the color space.
        
        If this color space has an ICC color profile, the sequence contains an element named ICCProfile. Some color spaces also have properties Gamma, Whitepoint and Blackpoint. Background information for these is available here.
        """
    def getRenderingIntent(self) -> int:
        """
        Query rendering intent of this color space.
        """
    def getType(self) -> int:
        """
        Query type of this color space.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class AdministrationProvider(XComponent_98dc0ab5, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    manages one, or more, complete sets of configuration data for administrative purposes and serves as a factory for objects that provide access to subsets of these shared configurations.
    
    Shared sets of configuration data usually serve to provide defaults, which are used if no individual settings are present. Depending on the data store multiple layers of defaults may be combined with a user-specific layer to make up the final configuration.
    
    Many aspects of the supported behavior depend strongly on the underlying data store and on the administrative structures it defines. With some data stores this service also enables access to individual user's configuration data by an administrator.
    
    On the other hand, in the simplest model there is only a single layer of default data which is accessible through this service.
    
    An implementation is usually obtained from a com.sun.star.lang.ServiceManager. The arguments passed to com.sun.star.lang.XMultiComponentFactory.createInstanceWithArgumentsAndContext() select the configuration data source. They may also define the scope of administrable data or contain credentials to be used to authorize the administrative access. Missing parameters may be filled in from the context or the environment.
    
    A ConfigurationProvider provides access to the personal layer of configuration data of the current user context. It should in most cases be used when using the configuration data, although for most contexts an AdministrationProvider can be used as a drop-in replacement.

    See Also:
        `API AdministrationProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1AdministrationProvider.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924

class XDesktopTask(XComponent_98dc0ab5):
    """
    use XFrame instead of this
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDesktopTask <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktopTask.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XDesktopTask']

    def close(self) -> bool:
        """
        use com.sun.star.util.XCloseable or com.sun.star.lang.XComponent.dispose() instead.
        """
    def initialize(self, TaskWindow: 'XWindow_713b0924') -> None:
        """
        use com.sun.star.lang.XInitialization instead.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0

class XSystemChildFactory(XInterface_8f010a43):
    """
    specifies a factory interface for creating system child windows.

    See Also:
        `API XSystemChildFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XSystemChildFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XSystemChildFactory']

    def createSystemChild(self, Parent: object, ProcessId: 'typing.Tuple[int, ...]', SystemType: int) -> 'XWindowPeer_99760ab0':
        """
        creates a system child window.
        
        You must check the machine ID and the process ID.
        WIN32: HWND.
        WIN16: HWND.
        
        JAVA: global reference to a java.awt.Component object provided from the JNI-API.
        
        MAC: (NSView*) pointer.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.uno
from typing_extensions import Literal
from .x_interface import XInterface as XInterface_8f010a43

class XCurrentContext(XInterface_8f010a43):
    """
    Task (thread) local execution context for UNO.
    
    Arbitrary values can be retrieved from the context.
    
    You have to use UNO runtime functions to obtain the current context in your target language.

    See Also:
        `API XCurrentContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XCurrentContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uno.XCurrentContext']

    def getValueByName(self, Name: str) -> object:
        """
        Gets a value from the context.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.binding
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_value_binding import XValueBinding as XValueBinding_271b0ed5
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0

class ValueBinding(XPropertySet_bc180bfa, XValueBinding_271b0ed5, XComponent_98dc0ab5, XModifyBroadcaster_fd990df0):
    """
    Service Class

    defines a component which allows access to a single value
    
    Read/Write access to the value represented by this component is supported, as well as (optionally) active broadcasting of value changes

    See Also:
        `API ValueBinding <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ValueBinding.html>`_
    """
    @property
    def ReadOnly(self) -> bool:
        """
        determines whether the value is currently readonly
        
        For instance, you could imagine a ValueBinding which represents a cell in a spreadsheet document, and whose value is readonly as long as the spreadsheet is locked.
        
        As long as this property is TRUE, the value binding should throw an InvalidBindingStateException when its XValueBinding.setValue() method is invoked.
        """
    @property
    def Relevant(self) -> bool:
        """
        determines the relevance of the value represented by the binding
        
        In a more complex scenario, where different form controls are bound to different values, which all are part of a larger data structure, some of the items in this data structure may not be relevant currently. This is indicated by the Relevant property being FALSE.
        
        XBindableValues which are bound to this binding may or may not react in certain ways on the (ir)relevance of their bound value.
        
        One possible reaction could be that user interface elements which are associated with the XBindableValue are disabled as long as Relevant is FALSE.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_coordinate_system import XCoordinateSystem as XCoordinateSystem_7ff0e31

class XChartType(XInterface_8f010a43):
    """

    See Also:
        `API XChartType <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartType.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XChartType']

    def createCoordinateSystem(self, DimensionCount: int) -> 'XCoordinateSystem_7ff0e31':
        """
        Creates a coordinate systems that fits the chart-type with its current settings and for the given dimension.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getChartType(self) -> str:
        """
        A string representation of the chart type.
        
        This needs to be the service-name which can be used to create a chart type.
        """
    def getRoleOfSequenceForSeriesLabel(self) -> str:
        """
        Returns the role of the XLabeledDataSequence of which the label will be taken to identify the DataSeries in dialogs or the legend.
        """
    def getSupportedMandatoryRoles(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of roles that are understood by this chart type.
        
        All roles must be listed in the order in which they are usually parsed. This ensures that gluing sequences together and splitting them up apart again results in the same structure as before.
        
        Note, that this does not involve optional roles, like error-bars.
        """
    def getSupportedOptionalRoles(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of roles that are understood in addition to the mandatory roles (see XChartType.getSupportedMandatoryRoles()).
        
        An example for an optional role are error-bars.
        """
    def getSupportedPropertyRoles(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence with supported property mapping roles.
        
        An example for a property mapping role is FillColor.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .content_provider_info import ContentProviderInfo as ContentProviderInfo_fd9c0df4
    from .x_content_provider import XContentProvider as XContentProvider_d4150cc0

class XContentProviderManager(XInterface_8f010a43):
    """
    makes it possible to query/register/deregister content providers.

    See Also:
        `API XContentProviderManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentProviderManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContentProviderManager']

    def deregisterContentProvider(self, Provider: 'XContentProvider_d4150cc0', Scheme: str) -> None:
        """
        deregisters a content provider.
        """
    def queryContentProvider(self, Identifier: str) -> 'XContentProvider_d4150cc0':
        """
        returns the currently active content provider for a content identifier.
        """
    def queryContentProviders(self) -> 'typing.Tuple[ContentProviderInfo_fd9c0df4, ...]':
        """
        returns a list of information on all registered content providers.
        """
    def registerContentProvider(self, Provider: 'XContentProvider_d4150cc0', Scheme: str, ReplaceExisting: bool) -> 'XContentProvider_d4150cc0':
        """
        registers a content provider for a specific URL template.
        
        This may be NULL, in which case a later XContentProvider.queryContent() with an XContentIdentifier that matches the Scheme will simply return NULL. These \"dummy\" content providers are useful in combination with other content providers that are registered on a wildcard URL template: For example, imagine that you want to route all http URLs to a HTTP content provider, but want to block all URLs for the server www.dont.go. One solution would be to register the HTTP content provider on the Scheme http, and to register a \"dummy\" (i.e., NULL) content provider on the Scheme \"http://www.dont.go\"([/?#].*)?.
        
        A URL template is a regular expression (represented as a string) that specifies a subset of the set of all possible URLs (this subset consists of exactly those URLs that match the regular expression). The language to denote the regular expressions is initially quite limited, but it may be extended in the future:
        
        A <scheme&gt: matches any URL of exactly the given scheme (ignoring case), keeping the extension from URL schemes to URL templates backwards compatible. The <simple&gt: regexps match any URL starting with a given string literal, followed by arbitrary characters (<simple-prefix&gt:), or by arbitrary characters that start with one of '/', '?', or '#', if any (<simple-authority&gt:), or by arbitrary characters not including any of '/', '?', or '#', followed by a given string literal, followed by arbitrary characters that start with one of '/', '?', or '#', if any. The comparison of string literals is done ignoring the case of ASCII letters. The <translation&gt: regexps match the same URLs as their <simple&gt: counterparts, but they also describe how a (local) URL is mapped to another (remote) URL. This mapping is only relevant for methods of the RemoteAccessContentProvider's XParameterizedContentProvider interface; in all other cases, <translation&gt: regexps have the same semantics as their <simple&gt: counterparts.
        
        FALSE: do not register, if another provider is already registered for the given URL template.

        Raises:
            com.sun.star.ucb.DuplicateProviderException: ``DuplicateProviderException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xsd
from typing_extensions import Literal


class DataTypeClass(object):
    """
    Const

    These constants specify the class used of an XDataType.

    See Also:
        `API DataTypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xsd_1_1DataTypeClass.html>`_
    """
    STRING: Literal[1]
    """
    specifies an XSD compliant string type
    """
    BOOLEAN: Literal[2]
    """
    specifies an XSD compliant boolean type
    """
    DECIMAL: Literal[3]
    """
    specifies an XSD compliant decimal type
    """
    FLOAT: Literal[4]
    """
    specifies an XSD compliant float type
    """
    DOUBLE: Literal[5]
    """
    specifies an XSD compliant double type
    """
    DURATION: Literal[6]
    """
    specifies an XSD compliant duration type
    """
    DATETIME: Literal[7]
    """
    specifies an XSD compliant datetime type
    """
    TIME: Literal[8]
    """
    specifies an XSD compliant time type
    """
    DATE: Literal[9]
    """
    specifies an XSD compliant date type
    """
    gYearMonth: Literal[10]
    """
    specifies an XSD compliant gYearMonth type
    """
    gYear: Literal[11]
    """
    specifies an XSD compliant gYear type
    """
    gMonthDay: Literal[12]
    """
    specifies an XSD compliant gMonthDay type
    """
    gDay: Literal[13]
    """
    specifies an XSD compliant gDay type
    """
    gMonth: Literal[14]
    """
    specifies an XSD compliant gMonth type
    """
    hexBinary: Literal[15]
    """
    specifies an XSD compliant hexBinary type
    """
    base64Binary: Literal[16]
    """
    specifies an XSD compliant base64Binary type
    """
    anyURI: Literal[17]
    """
    specifies an XSD compliant anyURI type
    """
    QName: Literal[18]
    """
    specifies an XSD compliant QName type
    """
    NOTATION: Literal[19]
    """
    specifies an XSD compliant NOTATION type
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal


class SpellFailure(object):
    """
    Const

    these define the various return types for spell checking to fail verification.
    
    A value of this type is part of the com.sun.star.linguistic2.XSpellAlternatives interface which is the return type for an unsuccessful spelling attempt.

    See Also:
        `API SpellFailure <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1SpellFailure.html>`_
    """
    IS_NEGATIVE_WORD: Literal[2]
    """
    The word is a negative one, that is, it should not be used.
    """
    CAPTION_ERROR: Literal[3]
    """
    The capitalization of the word is wrong.
    """
    SPELLING_ERROR: Literal[4]
    """
    The spelling of the word is wrong (or at least not known to be correct).
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection import XConnection as XConnection_a36a0b0c

class XDataSource(XInterface_8f010a43):
    """
    is used for establishing connections via a factory which is identified by its name.
    
    A DataSource object is typically registered by a naming service provider.

    See Also:
        `API XDataSource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDataSource.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XDataSource']

    def getConnection(self, user: str, password: str) -> 'XConnection_a36a0b0c':
        """
        attempts to establish a database connection.

        Raises:
            SQLException: ``SQLException``
        """
    def getLoginTimeout(self) -> int:
        """
        gets the maximum time in seconds that this data source can wait while attempting to connect to a database.
        
        A value of zero means that the timeout is the default system timeout if there is one; otherwise, it means that there is no timeout. When a DataSource object is created the login timeout is initially zero.

        Raises:
            SQLException: ``SQLException``
        """
    def setLoginTimeout(self, seconds: int) -> None:
        """
        sets the maximum time in seconds that this data source will wait while attempting to connect to a database.
        
        A value of zero specifies that the timeout is the default system timeout if there is one; otherwise, it specifies that there is no timeout. When a DataSource object is created the login timeout is initially zero.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.chart.accessible_chart_document_view import AccessibleChartDocumentView as AccessibleChartDocumentView
from .._pyi.chart.accessible_chart_element import AccessibleChartElement as AccessibleChartElement
from .._pyi.chart.area_diagram import AreaDiagram as AreaDiagram
from .._pyi.chart.bar_diagram import BarDiagram as BarDiagram
from .._pyi.chart.bubble_diagram import BubbleDiagram as BubbleDiagram
from .._pyi.chart.chart3_d_bar_properties import Chart3DBarProperties as Chart3DBarProperties
from .._pyi.chart.chart_area import ChartArea as ChartArea
from .._pyi.chart.chart_axis import ChartAxis as ChartAxis
from .._pyi.chart.chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier
from .._pyi.chart.chart_axis_y_supplier import ChartAxisYSupplier as ChartAxisYSupplier
from .._pyi.chart.chart_axis_z_supplier import ChartAxisZSupplier as ChartAxisZSupplier
from .._pyi.chart.chart_data import ChartData as ChartData
from .._pyi.chart.chart_data_array import ChartDataArray as ChartDataArray
from .._pyi.chart.chart_data_change_event import ChartDataChangeEvent as ChartDataChangeEvent
from .._pyi.chart.chart_data_point import ChartDataPoint as ChartDataPoint
from .._pyi.chart.chart_data_point_properties import ChartDataPointProperties as ChartDataPointProperties
from .._pyi.chart.chart_data_row import ChartDataRow as ChartDataRow
from .._pyi.chart.chart_data_row_properties import ChartDataRowProperties as ChartDataRowProperties
from .._pyi.chart.chart_data_value import ChartDataValue as ChartDataValue
from .._pyi.chart.chart_document import ChartDocument as ChartDocument
from .._pyi.chart.chart_grid import ChartGrid as ChartGrid
from .._pyi.chart.chart_legend import ChartLegend as ChartLegend
from .._pyi.chart.chart_line import ChartLine as ChartLine
from .._pyi.chart.chart_pie_segment_properties import ChartPieSegmentProperties as ChartPieSegmentProperties
from .._pyi.chart.chart_series_address import ChartSeriesAddress as ChartSeriesAddress
from .._pyi.chart.chart_statistics import ChartStatistics as ChartStatistics
from .._pyi.chart.chart_table_address_supplier import ChartTableAddressSupplier as ChartTableAddressSupplier
from .._pyi.chart.chart_title import ChartTitle as ChartTitle
from .._pyi.chart.chart_two_axis_x_supplier import ChartTwoAxisXSupplier as ChartTwoAxisXSupplier
from .._pyi.chart.chart_two_axis_y_supplier import ChartTwoAxisYSupplier as ChartTwoAxisYSupplier
from .._pyi.chart.diagram import Diagram as Diagram
from .._pyi.chart.dim3_d_diagram import Dim3DDiagram as Dim3DDiagram
from .._pyi.chart.donut_diagram import DonutDiagram as DonutDiagram
from .._pyi.chart.filled_net_diagram import FilledNetDiagram as FilledNetDiagram
from .._pyi.chart.line_diagram import LineDiagram as LineDiagram
from .._pyi.chart.net_diagram import NetDiagram as NetDiagram
from .._pyi.chart.pie_diagram import PieDiagram as PieDiagram
from .._pyi.chart.stackable_diagram import StackableDiagram as StackableDiagram
from .._pyi.chart.stock_diagram import StockDiagram as StockDiagram
from .._pyi.chart.time_increment import TimeIncrement as TimeIncrement
from .._pyi.chart.time_interval import TimeInterval as TimeInterval
from .._pyi.chart.x3_d_default_setter import X3DDefaultSetter as X3DDefaultSetter
from .._pyi.chart.x3_d_display import X3DDisplay as X3DDisplay
from .._pyi.chart.x_axis import XAxis as XAxis
from .._pyi.chart.x_axis_supplier import XAxisSupplier as XAxisSupplier
from .._pyi.chart.x_axis_x_supplier import XAxisXSupplier as XAxisXSupplier
from .._pyi.chart.x_axis_y_supplier import XAxisYSupplier as XAxisYSupplier
from .._pyi.chart.x_axis_z_supplier import XAxisZSupplier as XAxisZSupplier
from .._pyi.chart.x_chart_data import XChartData as XChartData
from .._pyi.chart.x_chart_data_array import XChartDataArray as XChartDataArray
from .._pyi.chart.x_chart_data_change_event_listener import XChartDataChangeEventListener as XChartDataChangeEventListener
from .._pyi.chart.x_chart_document import XChartDocument as XChartDocument
from .._pyi.chart.x_complex_description_access import XComplexDescriptionAccess as XComplexDescriptionAccess
from .._pyi.chart.x_date_categories import XDateCategories as XDateCategories
from .._pyi.chart.x_diagram import XDiagram as XDiagram
from .._pyi.chart.x_diagram_positioning import XDiagramPositioning as XDiagramPositioning
from .._pyi.chart.x_second_axis_title_supplier import XSecondAxisTitleSupplier as XSecondAxisTitleSupplier
from .._pyi.chart.x_statistic_display import XStatisticDisplay as XStatisticDisplay
from .._pyi.chart.x_two_axis_x_supplier import XTwoAxisXSupplier as XTwoAxisXSupplier
from .._pyi.chart.x_two_axis_y_supplier import XTwoAxisYSupplier as XTwoAxisYSupplier
from .._pyi.chart.xy_diagram import XYDiagram as XYDiagram



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.accessibility
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43


class AccessibleRelation(object):
    """
    Struct Class

    An AccessibleRelation object defines a one-to-many relation.
    
    The represented relation points from the implementing object to a set of target objects.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleRelation <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1accessibility_1_1AccessibleRelation.html>`_
    """
    typeName: Literal['com.sun.star.accessibility.AccessibleRelation']

    def __init__(self, TargetSet: typing.Optional[typing.Tuple[XInterface_8f010a43, ...]] = ..., RelationType: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            TargetSet (typing.Tuple[XInterface, ...], optional): TargetSet value.
            RelationType (int, optional): RelationType value.
        """


    @property
    def TargetSet(self) -> typing.Tuple[XInterface_8f010a43, ...]:
        """
        Set of objects that are the relation's targets.
        
        The content of this set is undefined if the relation's type is INVALID. The set must not contain references to one object more than once.
        """


    @property
    def RelationType(self) -> int:
        """
        Type of the relation.
        
        Its value has to be one of the constants defined by AccessibleRelationType. If that value is INVALID then the whole relation is regarded as invalid. The content of the TargetSet is then undefined.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe

class XGridPeer(XInterface_8f010a43):
    """
    represents the window peer of a GridControl and allows you to set and retrieve the model data.
    
    Usually, the columns used are the columns as supplied by the grid control model.
    
    You should use this interface only if you know exactly what you are doing. Tampering with the columns of a grid control which is part of a complex form can really hurt...
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XGridPeer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XGridPeer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XGridPeer']

    def getColumns(self) -> 'XIndexContainer_1c040ebe':
        """
        retrieves the currently used column definitions of the peer.
        """
    def setColumns(self, aColumns: 'XIndexContainer_1c040ebe') -> None:
        """
        sets the column definition for the peer.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from .x_simple_file_access import XSimpleFileAccess as XSimpleFileAccess_dede0cd6
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XSimpleFileAccess2(XSimpleFileAccess_dede0cd6):
    """
    This is an extension to the interface XSimpleFileAccess.

    See Also:
        `API XSimpleFileAccess2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XSimpleFileAccess2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XSimpleFileAccess2']

    def writeFile(self, FileURL: str, data: 'XInputStream_98d40ab4') -> None:
        """
        Overwrites the file content with the given data.
        
        If the file does not exist, it will be created.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from .x_popup_menu_controller import XPopupMenuController as XPopupMenuController_29740f38
from .x_status_listener import XStatusListener as XStatusListener_e2740d35
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class PopupMenuController(XDispatchProvider_fc690de6, XPopupMenuController_29740f38, XStatusListener_e2740d35, XComponent_98dc0ab5, XInitialization_d46c0cca):
    """
    Service Class

    provides access to a pop-up menu controller.
    
    A pop-up menu controller is used to make special functions available to users, which depend on runtime or context specific conditions.
    A typical example for a pop-up menu controller can be a recent file list implementation which provides a list of latest files that a user has worked on. This list gets changes consistently during a work session.
    
    **since**
    
        OOo 2.0

    See Also:
        `API PopupMenuController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1PopupMenuController.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from .shape import Shape as Shape_85cc09e5
if typing.TYPE_CHECKING:
    from ..frame.x_model import XModel as XModel_7a6e095c

class OLE2Shape(Shape_85cc09e5):
    """
    Service Class

    This service is for an OLE shape.

    See Also:
        `API OLE2Shape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1OLE2Shape.html>`_
    """
    @property
    def CLSID(self) -> str:
        """
        If you get this property you get the CLSID of the OLE2 document stream contained in this OLE2 shape.
        
        If you set it, an empty OLE2 document stream with this CLSID is created within this OLE2 shape.
        """
    @property
    def IsInternal(self) -> bool:
        """
        This property returns TRUE for all OLE2 that are internal Office components.
        """
    @property
    def Model(self) -> 'XModel_7a6e095c':
        """
        This is the model for the OLE2 inside this shape.
        
        This property returns an empty reference if the OLE2 is not an Office component.
        """
    @property
    def PersistName(self) -> str:
        """
        this is the internal storage name that keeps this OLE2 persist.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
"""
Const

to be used in lingu-service events.

These values define the flags which may be logically combined to build the event type of a com.sun.star.linguistic2.LinguServiceEvent

**since**

    OOo 3.0.1

See Also:
    `API LinguServiceEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1LinguServiceEventFlags.html>`_
"""
SPELL_CORRECT_WORDS_AGAIN: Literal[1]
"""
The spelling of previously correct words should be checked again.
"""
SPELL_WRONG_WORDS_AGAIN: Literal[2]
"""
The spelling of previously misspelled words should be checked again.
"""
HYPHENATE_AGAIN: Literal[4]
"""
The hyphenation of words may have changed.
"""
PROOFREAD_AGAIN: Literal[8]
"""
Request new proofreading of the document.

**since**

    OOo 3.0.1
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.java
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XJavaThreadRegister_11(XInterface_8f010a43):
    """
    must be implemented by the user of the XJavaThreadRegister_11.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XJavaThreadRegister_11 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1java_1_1XJavaThreadRegister__11.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.java.XJavaThreadRegister_11']

    def isThreadAttached(self) -> bool:
        """
        returns TRUE if the current thread is already attached to the VM otherwise FALSE.
        """
    def registerThread(self) -> None:
        """
        registers the current thread.
        
        This method should be called every time a JNI function is called from Java.
        """
    def revokeThread(self) -> None:
        """
        revokes the current thread from the list of registered threads.
        
        This method should be called at the end of every JNI call from Java.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.security.access_control_exception import AccessControlException as AccessControlException
from .._pyi.security.access_controller import AccessController as AccessController
from .._pyi.security.all_permission import AllPermission as AllPermission
from .._pyi.security.cert_alt_name_entry import CertAltNameEntry as CertAltNameEntry
from .._pyi.security.certificate_container import CertificateContainer as CertificateContainer
from .._pyi.security.certificate_exception import CertificateException as CertificateException
from .._pyi.security.cryptography_exception import CryptographyException as CryptographyException
from .._pyi.security.document_digital_signatures import DocumentDigitalSignatures as DocumentDigitalSignatures
from .._pyi.security.document_signature_information import DocumentSignatureInformation as DocumentSignatureInformation
from .._pyi.security.encryption_exception import EncryptionException as EncryptionException
from .._pyi.security.key_exception import KeyException as KeyException
from .._pyi.security.no_password_exception import NoPasswordException as NoPasswordException
from .._pyi.security.policy import Policy as Policy
from .._pyi.security.runtime_permission import RuntimePermission as RuntimePermission
from .._pyi.security.security_infrastructure_exception import SecurityInfrastructureException as SecurityInfrastructureException
from .._pyi.security.signature_exception import SignatureException as SignatureException
from .._pyi.security.x_access_control_context import XAccessControlContext as XAccessControlContext
from .._pyi.security.x_access_controller import XAccessController as XAccessController
from .._pyi.security.x_action import XAction as XAction
from .._pyi.security.x_certificate import XCertificate as XCertificate
from .._pyi.security.x_certificate_container import XCertificateContainer as XCertificateContainer
from .._pyi.security.x_certificate_extension import XCertificateExtension as XCertificateExtension
from .._pyi.security.x_document_digital_signatures import XDocumentDigitalSignatures as XDocumentDigitalSignatures
from .._pyi.security.x_policy import XPolicy as XPolicy
from .._pyi.security.x_san_extension import XSanExtension as XSanExtension



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script.vba
from typing_extensions import Literal


class VBAEventId(object):
    """
    Const

    Constants used to identify VBA document events.
    
    If one of these events is fired, a specific VBA macro in a specific document code module will be executed.
    
    Each event expects some specific arguments to be passed to XVBAEventProcessor.processVbaEvent().

    See Also:
        `API VBAEventId <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAEventId.html>`_
    """
    NO_EVENT: Literal[-1]
    """
    An identifier not corresponding to any VBA document event.
    """
    AUTO_NEW: Literal[1]
    """
    New document opened from template.
    
    No arguments.
    """
    AUTO_OPEN: Literal[2]
    """
    Document opened (loaded).
    
    No arguments.
    """
    AUTO_CLOSE: Literal[3]
    """
    Document about to be closed.
    
    No arguments.
    """
    AUTO_EXEC: Literal[4]
    """
    Application start.
    
    No arguments.
    """
    AUTO_EXIT: Literal[5]
    """
    Application exit.
    
    No arguments.
    """
    DOCUMENT_NEW: Literal[1001]
    """
    New text document opened from template.
    
    No arguments.
    """
    DOCUMENT_OPEN: Literal[1002]
    """
    Text document opened (loaded).
    
    No arguments.
    """
    DOCUMENT_CLOSE: Literal[1003]
    """
    Document about to be closed.
    
    No arguments.
    """
    WORKBOOK_ACTIVATE: Literal[2001]
    """
    Document activated.
    
    No arguments.
    """
    WORKBOOK_DEACTIVATE: Literal[2002]
    """
    Document deactivated.
    
    No arguments.
    """
    WORKBOOK_OPEN: Literal[2003]
    """
    Document opened (loaded).
    
    No arguments.
    """
    WORKBOOK_BEFORECLOSE: Literal[2004]
    """
    Document about to be closed.
    
    Arguments: [out] boolean bCancel.
    """
    WORKBOOK_BEFOREPRINT: Literal[2005]
    """
    Document about to be printed.
    
    Arguments: [out] boolean bCancel.
    """
    WORKBOOK_BEFORESAVE: Literal[2006]
    """
    Document about to be saved.
    
    Arguments: boolean bSaveAs, [out] boolean bCancel.
    """
    WORKBOOK_AFTERSAVE: Literal[2007]
    """
    Document has been saved.
    
    Arguments: boolean bSuccess.
    """
    WORKBOOK_NEWSHEET: Literal[2008]
    """
    New sheet inserted.
    
    Arguments: short nSheet.
    """
    WORKBOOK_WINDOWACTIVATE: Literal[2009]
    """
    Document window has been activated.
    
    Arguments: XController aController.
    """
    WORKBOOK_WINDOWDEACTIVATE: Literal[2010]
    """
    Document window has been deactivated.
    
    Arguments: XController aController.
    """
    WORKBOOK_WINDOWRESIZE: Literal[2011]
    """
    Document window has been resized.
    
    Arguments: XController aController.
    """
    WORKSHEET_ACTIVATE: Literal[2101]
    """
    Worksheet has been activated (made visible).
    
    Arguments: short nSheet.
    """
    WORKSHEET_DEACTIVATE: Literal[2102]
    """
    Worksheet has been activated (made visible).
    
    Arguments: short nSheet.
    """
    WORKSHEET_BEFOREDOUBLECLICK: Literal[2103]
    """
    Double click in the sheet.
    
    Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
    """
    WORKSHEET_BEFORERIGHTCLICK: Literal[2104]
    """
    Right click in the sheet.
    
    Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
    """
    WORKSHEET_CALCULATE: Literal[2105]
    """
    Cells in sheet have been recalculated.
    
    Arguments: short nSheet.
    """
    WORKSHEET_CHANGE: Literal[2106]
    """
    Cells in sheet have been changed.
    
    Arguments: XRange/XSheetCellRangeContainer aRange.
    """
    WORKSHEET_SELECTIONCHANGE: Literal[2107]
    """
    Selection in sheet has been changed.
    
    Arguments: XRange/XSheetCellRangeContainer aRange.
    """
    WORKSHEET_FOLLOWHYPERLINK: Literal[2108]
    """
    Hyperlink has been clicked.
    
    Arguments: XCell aCell.
    """
    USERDEFINED_START: Literal[1000000]
    """
    Implementations are allowed to use identifiers above this value for any internal purpose.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
from .x_frame_action_listener import XFrameActionListener as XFrameActionListener_26250efa
from .x_layout_manager import XLayoutManager as XLayoutManager_d4510ca4
from .x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster_d3f61310
from .x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor_53e5100f
from ..ui.xui_configuration_listener import XUIConfigurationListener as XUIConfigurationListener_34e90f7a

class XLayoutManager2(XFrameActionListener_26250efa, XLayoutManager_d4510ca4, XLayoutManagerEventBroadcaster_d3f61310, XMenuBarMergingAcceptor_53e5100f, XUIConfigurationListener_34e90f7a):
    """
    Unified interface for LayoutManager service.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XLayoutManager2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XLayoutManager2']





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const

defines the restart behavior

See Also:
    `API AnimationRestart <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationRestart.html>`_
"""
DEFAULT: Literal[0]
"""
The restart behavior for the element is determined by the value of the XTiming.RestartDefault attribute.

This is the default value for the XTiming.Restart attribute.
"""
INHERIT: Literal[0]
"""
Specifies that the value of this attribute (and of the restart behavior) are inherited from the XTiming.RestartDefault value of the parent element.

If there is no parent element, the value is AnimationRestart.ALWAYS. This is the default value for the XTiming.RestartDefault attribute.
"""
ALWAYS: Literal[1]
"""
The element can be restarted at any time.
"""
WHEN_NOT_ACTIVE: Literal[2]
"""
The element can only be restarted when it is not active (i.e.

it can be restarted after the active end). Attempts to restart the element during its active duration are ignored.
"""
NEVER: Literal[3]
"""
The element cannot be restarted for the remainder of the current simple duration of the parent time container.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d

class XMenuBarMergingAcceptor(XInterface_8f010a43):
    """
    provides functions to set and remove a merged menu bar for inplace editing.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XMenuBarMergingAcceptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XMenuBarMergingAcceptor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XMenuBarMergingAcceptor']

    def removeMergedMenuBar(self) -> None:
        """
        removes a previously set merged menu bar and sets a previously created menu bar back.
        """
    def setMergedMenuBar(self, xMergedMenuBar: 'XIndexAccess_f0910d6d') -> bool:
        """
        allows to set a merged menu bar.
        
        This function is normally used to provide inplace editing where functions from two application parts, container application and embedded object, are available to the user simultaneously. A menu bar which is set by this method has a higher priority than others created by com.sun.star.frame.XLayoutManager interface. Settings of a merged menu bar cannot be retrieved.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from .data_settings import DataSettings as DataSettings_a3000b0c
from ..sdbcx.descriptor import Descriptor as Descriptor_a5200b3b
from ..sdbcx.x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9
from ..sdbcx.x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory_46170fe5

class QueryDescriptor(DataSettings_a3000b0c, Descriptor_a5200b3b, XColumnsSupplier_f0600da9, XDataDescriptorFactory_46170fe5):
    """
    Service Class

    is a stored definition of a SQL \"Select statement\".
    
    It can be used, if there is a need to execute SQL statement more than once or if you want to format the query result fields different from the underlying table definitions.

    See Also:
        `API QueryDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1QueryDescriptor.html>`_
    """
    @property
    def Command(self) -> str:
        """
        is the command of the query, this is typically a select statement.
        """
    @property
    def EscapeProcessing(self) -> bool:
        """
        should we use escape processing for the query.
        """
    @property
    def UpdateCatalogName(self) -> str:
        """
        is the name of the update table catalog.
        """
    @property
    def UpdateSchemaName(self) -> str:
        """
        is the name of the update table schema.
        """
    @property
    def UpdateTableName(self) -> str:
        """
        is the name of the table which should be updated.
        
        This is usually used for queries which relate on more than one table.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .formula_token import FormulaToken as FormulaToken_bd1c0bf8
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XFormulaParser(ABC):
    """
    converts between text and token representations of formulas.

    See Also:
        `API XFormulaParser <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaParser.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XFormulaParser']

    def parseFormula(self, aFormula: str, aReferencePos: 'CellAddress_ae5f0b56') -> 'typing.Tuple[FormulaToken_bd1c0bf8, ...]':
        """
        parses a formula into a sequence of tokens.
        """
    def printFormula(self, aTokens: 'typing.Tuple[FormulaToken_bd1c0bf8, ...]', aReferencePos: 'CellAddress_ae5f0b56') -> str:
        """
        converts a formula into a string.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
import typing
from .xuri import XURI as XURI_5682078c
if typing.TYPE_CHECKING:
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14

class XMetadatable(XURI_5682078c):
    """
    marks an object representing an ODF element that may have RDF meta data attached.
    
    To make using ODF elements as part of RDF statements more convenient, this interface inherits from XURI. The URI is constructed by concatenating the URI of the document, the stream name, a fragment separator, and the XML ID.
    
    Note that using the XURI interface on an instance of XMetadatable may have the side effect of creating a metadata reference for the instance.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XMetadatable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XMetadatable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rdf.XMetadatable']

    def ensureMetadataReference(self) -> None:
        """
        creates a metadata reference for this object, if necessary.
        
        If this object already has a metadata reference, do nothing; otherwise, create metadata reference with a fresh, unique XML ID and assign it to the MetadataReference attribute.
        """
    @property
    def MetadataReference(self) -> 'StringPair_a4bc0b14':
        """
        a metadata reference, comprising the stream name and the XML ID.
        
        Note that this metadata reference must be unique for the ODF document. This implies that the XML ID part must be unique for every stream. A pair of two empty strings signifies \"no metadata reference\". For example: Pair(\"content.xml\", \"foo-element-1\")
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..awt.font_slant import FontSlant as FontSlant_849509ed
    from ..lang.locale import Locale as Locale_70d308fa
    from ..style.vertical_alignment import VerticalAlignment as VerticalAlignment_8d0e12
    from ..util.color import Color as Color_68e908c5

class XReportControlFormat(ABC):
    """
    specifies a format condition for a control.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XReportControlFormat <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlFormat.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XReportControlFormat']

    @property
    def CharAutoKerning(self) -> bool:
        """
        optional property to determine whether the kerning tables from the current font are used.
        
        Automatic kerning applies a spacing in between certain pairs of characters to make the text look better.
        """

    @property
    def CharCaseMap(self) -> int:
        """
        optional property which contains the value of the case-mapping of the text for formatting and displaying.
        """

    @property
    def CharColor(self) -> 'Color_68e908c5':
        """
        specifies the text color (RGB) of the control.
        """

    @property
    def CharCombineIsOn(self) -> bool:
        """
        determines whether text is formatted in two lines.
        
        It is linked to the properties CharCombinePrefix and CharCombineSuffix.
        """

    @property
    def CharCombinePrefix(self) -> str:
        """
        contains the prefix (usually parenthesis) before text that is formatted in two lines.
        
        It is linked to the properties CharCombineIsOn and CharCombineSuffix.
        """

    @property
    def CharCombineSuffix(self) -> str:
        """
        contains the suffix (usually parenthesis) after text that is formatted in two lines.
        
        It is linked to the properties CharCombineIsOn and CharCombinePrefix.
        """

    @property
    def CharContoured(self) -> bool:
        """
        specifies if the characters are formatted and displayed with a contour effect.
        """

    @property
    def CharEmphasis(self) -> int:
        """
        contains the font emphasis value as com.sun.star.text.FontEmphasis.
        """

    @property
    def CharEscapement(self) -> int:
        """
        specifies the percentage by which to raise/lower superscript/subscript characters.
        
        Negative values denote subscripts and positive values superscripts.
        """

    @property
    def CharEscapementHeight(self) -> int:
        """
        This is the additional height used for subscript or superscript characters in units of percent.
        
        For subscript characters the value is negative and for superscript characters positive.
        """

    @property
    def CharFlash(self) -> bool:
        """
        If this optional property is TRUE, then the characters are flashing.
        """

    @property
    def CharFontCharSet(self) -> int:
        """
        This attribute contains the text encoding of the font as specified in com.sun.star.awt.CharSet.
        """

    @property
    def CharFontCharSetAsian(self) -> int:
        """
        This property contains the text encoding of the font as specified in com.sun.star.awt.CharSet.
        """

    @property
    def CharFontCharSetComplex(self) -> int:
        """
        This property contains the text encoding of the font as specified in com.sun.star.awt.CharSet.
        """

    @property
    def CharFontFamily(self) -> int:
        """
        This attribute contains font family as specified in com.sun.star.awt.FontFamily .
        """

    @property
    def CharFontFamilyAsian(self) -> int:
        """
        This property contains font family as specified in com.sun.star.awt.FontFamily .
        """

    @property
    def CharFontFamilyComplex(self) -> int:
        """
        This property contains font family as specified in com.sun.star.awt.FontFamily .
        """

    @property
    def CharFontName(self) -> str:
        """
        This attribute specifies the name of the font style.
        
        It may contain more than one name separated by comma.
        """

    @property
    def CharFontNameAsian(self) -> str:
        """
        This property specifies the name of the font style.
        
        It may contain more than one name separated by comma.
        """

    @property
    def CharFontNameComplex(self) -> str:
        """
        This property specifies the name of the font style.
        
        It may contain more than one name separated by comma.
        """

    @property
    def CharFontPitch(self) -> int:
        """
        This attribute contains the font pitch as specified in com.sun.star.awt.FontPitch.
        """

    @property
    def CharFontPitchAsian(self) -> int:
        """
        This property contains the font pitch as specified in com.sun.star.awt.FontPitch.
        """

    @property
    def CharFontPitchComplex(self) -> int:
        """
        This property contains the font pitch as specified in com.sun.star.awt.FontPitch.
        """

    @property
    def CharFontStyleName(self) -> str:
        """
        This attribute contains the name of the font style.
        
        This attribute may be empty.
        """

    @property
    def CharFontStyleNameAsian(self) -> str:
        """
        This property contains the name of the font style.
        
        This property may be empty.
        """

    @property
    def CharFontStyleNameComplex(self) -> str:
        """
        This property contains the name of the font style.
        
        This property may be empty.
        """

    @property
    def CharHeight(self) -> float:
        """
        This value contains the height of the characters in point.
        """

    @property
    def CharHeightAsian(self) -> float:
        """
        This value contains the height of the characters in point.
        """

    @property
    def CharHeightComplex(self) -> float:
        """
        This value contains the height of the characters in point.
        """

    @property
    def CharHidden(self) -> bool:
        """
        If this optional property is TRUE, then the characters are invisible.
        
        **since**
        
            OOo 2.0
        """

    @property
    def CharKerning(self) -> int:
        """
        optional property which contains the value of the kerning of the characters.
        """

    @property
    def CharLocale(self) -> 'Locale_70d308fa':
        """
        contains the value of the locale.
        """

    @property
    def CharLocaleAsian(self) -> 'Locale_70d308fa':
        """
        contains the value of the locale.
        """

    @property
    def CharLocaleComplex(self) -> 'Locale_70d308fa':
        """
        contains the value of the locale.
        """

    @property
    def CharPosture(self) -> 'FontSlant_849509ed':
        """
        This attribute contains the value of the posture of the document.
        """

    @property
    def CharPostureAsian(self) -> 'FontSlant_849509ed':
        """
        This property contains the value of the posture of the document.
        """

    @property
    def CharPostureComplex(self) -> 'FontSlant_849509ed':
        """
        This property contains the value of the posture of the document.
        """

    @property
    def CharRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """

    @property
    def CharRotation(self) -> int:
        """
        determines the rotation of a character in degree.
        
        Depending on the implementation only certain values may be allowed.
        """

    @property
    def CharScaleWidth(self) -> int:
        """
        determines the percentage value for scaling the width of characters.
        
        The value refers to the original width which is denoted by 100, and it has to be greater than 0.
        """

    @property
    def CharShadowed(self) -> bool:
        """
        specifies if the characters are formatted and displayed with a shadow effect.
        """

    @property
    def CharStrikeout(self) -> int:
        """
        determines the type of the strike out of the character.
        """

    @property
    def CharUnderline(self) -> int:
        """
        This attribute contains the value for the character underline.
        """

    @property
    def CharUnderlineColor(self) -> 'Color_68e908c5':
        """
        specifies the text line color (RGB) of the control.
        """

    @property
    def CharWeight(self) -> float:
        """
        This attribute contains the value of the font weight.
        """

    @property
    def CharWeightAsian(self) -> float:
        """
        This property contains the value of the font weight.
        """

    @property
    def CharWeightComplex(self) -> float:
        """
        This property contains the value of the font weight.
        """

    @property
    def CharWordMode(self) -> bool:
        """
        If this attribute is TRUE, the underline and strike-through properties are not applied to white spaces.
        """

    @property
    def ControlBackground(self) -> 'Color_68e908c5':
        """
        specifies the background color (RGB) of the control.
        """

    @property
    def ControlBackgroundTransparent(self) -> bool:
        """
        determines if the background color is set to transparent.
        """

    @property
    def ControlTextEmphasis(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """

    @property
    def FontDescriptor(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font attributes of the text in the control.
        """

    @property
    def FontDescriptorAsian(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font attributes of the text in the control.
        """

    @property
    def FontDescriptorComplex(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font attributes of the text in the control.
        """

    @property
    def HyperLinkName(self) -> str:
        """
        contains the name of the hyperlink (if set).
        """

    @property
    def HyperLinkTarget(self) -> str:
        """
        contains the name of the target for a hyperlink (if set).
        """

    @property
    def HyperLinkURL(self) -> str:
        """
        contains the URL of a hyperlink (if set).
        """

    @property
    def ParaAdjust(self) -> int:
        """
        specifies the horizontal alignment of the text.
        """

    @property
    def UnvisitedCharStyleName(self) -> str:
        """
        contains the character style name for unvisited hyperlinks.
        """

    @property
    def VerticalAlign(self) -> 'VerticalAlignment_8d0e12':
        """
        specifies the vertical alignment of the text in the control.
        """

    @property
    def VisitedCharStyleName(self) -> str:
        """
        contains the character style name for visited hyperlinks.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2.data
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_data_sequence import XDataSequence as XDataSequence_11f00e1f
    from .x_data_source import XDataSource as XDataSource_f6340d57
    from ...sheet.x_range_selection import XRangeSelection as XRangeSelection_e1310d0c

class XDataProvider(XInterface_8f010a43):
    """
    An application that provides data for a chart must implement this interface.

    See Also:
        `API XDataProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.data.XDataProvider']

    def createDataSequenceByRangeRepresentation(self, aRangeRepresentation: str) -> 'XDataSequence_11f00e1f':
        """
        creates a single data sequence for the given data range.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createDataSequenceByRangeRepresentationPossible(self, aRangeRepresentation: str) -> bool:
        """
        If TRUE is returned, a call to createDataSequenceByRangeRepresentation with the same argument must return a valid XDataSequence object.
        
        If FALSE is returned, createDataSequenceByRangeRepresentation throws an exception.
        """
    def createDataSequenceByValueArray(self, aRole: str, aValueArray: str, aRoleQualifier: str) -> 'XDataSequence_11f00e1f':
        """
        Creates a single data sequence from the string value array representation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createDataSource(self, aArguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XDataSource_f6340d57':
        """
        Creates a data source object that matches the given range representation string.
        
        This can be used for creating the necessary data for a new chart out of a previously selected range of cells in a spreadsheet.
        
        For spreadsheets and text document tables there exists a service TabularDataProviderArguments describing valid values for this list.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createDataSourcePossible(self, aArguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> bool:
        """
        If TRUE is returned, a call to createDataSource with the same arguments must return a valid XDataSequence object.
        
        If FALSE is returned, createDataSource throws an exception.
        """
    def detectArguments(self, xDataSource: 'XDataSource_f6340d57') -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Tries to find out with what parameters the passed DataSource most probably was created.
        
        if xDataSource is a data source that was created with createDataSource(), the arguments returned here should be the same than the ones passed to the function. Of course, this cannot be guaranteed. However, if detection is ambiguous, the returned arguments should be empty.
        
        This method may merge representation strings together if adjacent ranges appear successively in the range identifiers. E.g., if the first range refers to \"$Sheet1.$A$1:$A$8\" and the second range refers to \"$Sheet1.$B$1:$B$8\", those should be merged together to \"$Sheet1.$A$1:$B$8\".
        """
    def getRangeSelection(self) -> 'XRangeSelection_e1310d0c':
        """
        Returns a component that is able to change a given range representation to another one.
        
        This usually is a controller-component that uses the GUI to allow a user to select a new range.
        
        This method may return nothing, if it does not support range selection or if there is no current controller available that offers the functionality.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2.data
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .highlighted_range import HighlightedRange as HighlightedRange_403d0f62
    from ...view.x_selection_change_listener import XSelectionChangeListener as XSelectionChangeListener_58bf104d

class XRangeHighlighter(XInterface_8f010a43):
    """

    See Also:
        `API XRangeHighlighter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XRangeHighlighter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.data.XRangeHighlighter']

    def addSelectionChangeListener(self, xListener: 'XSelectionChangeListener_58bf104d') -> None:
        """
        registers an event listener, which is called when the selection is changed and affects different source ranges
        """
    def getSelectedRanges(self) -> 'typing.Tuple[HighlightedRange_403d0f62, ...]':
        """
        Returns a list of ranges that are used by objects that are currently selected.
        """
    def removeSelectionChangeListener(self, xListener: 'XSelectionChangeListener_58bf104d') -> None:
        """
        unregisters an event listener which was registered with XRangeHighlighter.addSelectionChangeListener() before.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from ..drawing.x_shape import XShape as XShape_8fd00a3d
from .base_frame_properties import BaseFrameProperties as BaseFrameProperties_b990e60
from .text_content import TextContent as TextContent_a6810b4d

class BaseFrame(BaseFrameProperties_b990e60, TextContent_a6810b4d, XPropertySet_bc180bfa, XNamed_a6520b08, XShape_8fd00a3d):
    """
    Service Class

    specifies the base service of text frames, graphic objects, and embedded objects

    See Also:
        `API BaseFrame <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1BaseFrame.html>`_
    """
    @property
    def FrameStyleName(self) -> str:
        """
        contains the name of the frame style that is applied to this object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# TypeDef
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2.data
import typing

DataSequenceRole = typing.NewType('DataSequenceRole', str)
"""
TypeDef type alias

a string that states in what way a DataSequence should be used.

If this property is an empty string, no proposition about usage is made.

The strings can have any value. However some values are predefined and should always be interpreted in the same way.

In a candle-stick chart you have the following roles:

See Also:
    `API DataSequenceRole <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html#a340775895b509a7f80ba895767123429>`_
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Constants to specify the type of a parsed token.

Set by XCharacterClassification.parseAnyToken() and XCharacterClassification.parsePredefinedToken() in ParseResult.TokenType.

See Also:
    `API KParseType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KParseType.html>`_
"""
ONE_SINGLE_CHAR: Literal[1]
"""
One single character like ! # ; : $ et al.
"""
BOOLEAN: Literal[2]
"""
A Boolean operator like <, >, <>, =, <=, >=.
"""
IDENTNAME: Literal[4]
"""
A name matching the conditions passed.
"""
SINGLE_QUOTE_NAME: Literal[8]
"""
\"A single-quoted name matching the conditions passed ( 'na\\'me' ).\" \"Dequoted name in ParseResult.DequotedNameOrString ( na'me ).\"
"""
DOUBLE_QUOTE_STRING: Literal[16]
"""
A double-quoted string ( \"str\\\"i\"\"ng\" ).

Dequoted string in ParseResult.DequotedNameOrString ( str\"i\"ng ).
"""
ASC_NUMBER: Literal[32]
"""
A number where all digits are ASCII characters.

Numerical value in ParseResult.Value.
"""
UNI_NUMBER: Literal[64]
"""
A number where at least some digits are Unicode (and maybe ASCII) characters.

Numerical value inKParseType ParseResult.Value.
"""
MISSING_QUOTE: Literal[1073741824]
"""
Set (ored) if SINGLE_QUOTE_NAME or DOUBLE_QUOTE_STRING has no closing quote.
"""
ANY_NUMBER: str
"""
Any ASCII or Unicode number.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.container
from typing_extensions import Literal
import typing
from .x_map import XMap as XMap_90a60a41
if typing.TYPE_CHECKING:
    from .x_enumeration import XEnumeration as XEnumeration_f2180daa

class XEnumerableMap(XMap_90a60a41):
    """
    extends XMap with enumeration capabilities.
    
    No assumption should be made about the ordering of the elements returned by the various enumerators. In particular, you cannot assume the elements are returned in the same order as they were inserted. Also, you should not expect the XMap implementation to make use of a possibly existing strict ordering defined on the domain of all possible key values.
    
    You can create enumerators for the keys of the map, its values, and its key-value pairs.
    
    In all cases, you can create an isolated enumerator, which works on a copy of the map's content. Such an iterator is not affected by changes done to the map after creation of the enumerator.
    
    On the contrary, an enumerator which is non-isolated works directly on the map data. This is less expensive than an isolated enumerator, but means that changes to the map while an enumeration is running potentially invalidate your enumerator. The concrete behavior in this case is undefined, it's up to the service implementing the XEnumerableMap interface to specify it in more detail.
    
    Implementations of this interface might decide to support only isolated enumerators, or only non-isolated enumerators. Again, it's up to the service to specify this. Requesting an enumerator type which is not supported will generally result in a com.sun.star.lang.NoSupportException being thrown.

    See Also:
        `API XEnumerableMap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XEnumerableMap.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.container.XEnumerableMap']

    def createElementEnumeration(self, Isolated: bool) -> 'XEnumeration_f2180daa':
        """
        creates an enumerator for the key-value pairs of the map
        
        The elements returned by the enumerator are instances of com.sun.star.beans.Pair, holding the key-value-pairs which are part of the map.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    def createKeyEnumeration(self, Isolated: bool) -> 'XEnumeration_f2180daa':
        """
        creates an enumerator for the keys of the map

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    def createValueEnumeration(self, Isolated: bool) -> 'XEnumeration_f2180daa':
        """
        creates an enumerator for the values of the map

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame.status
from typing_extensions import Literal
"""
Const

these constants describe a state of an ItemStatus.

**since**

    OOo 2.0

See Also:
    `API ItemState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame_1_1status_1_1ItemState.html>`_
"""
UNKNOWN: Literal[0]
"""
specifies an unknown state.
"""
DISABLED: Literal[1]
"""
specifies that the property is currently disabled.
"""
READ_ONLY: Literal[2]
"""
specifies that the property is currently read-only.

Deprecated: There is no equivalent in SfxItemState anymore due to not being used, so remove for simplification reasons and to prepare rework of Item/ItemSet/ItemPool stuff.

There are only three usages of .ItemState in the code which all set the internal SfxItem to SfxVoidItem when triggered, which is equivalent to state SfxItemState.DISABLED (see e.g. SfxItemSet.GetItemState), so READ_ONLY gets not used in internal handling, even when eventually existing UNO API usages hand it over the office.
"""
DONT_CARE: Literal[16]
"""
specifies that the property is currently in a don't care state.

This is normally used if a selection provides more than one state for a property at the same time.
"""
DEFAULT_VALUE: Literal[32]
"""
specifies that the property is currently in a default state.
"""
SET: Literal[64]
"""
specifies that the property is currently in a set state.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_report_control_format import XReportControlFormat as XReportControlFormat_3d4e0fc2

class XFormatCondition(XPropertySet_bc180bfa, XReportControlFormat_3d4e0fc2):
    """
    specifies a format condition for a control.

    See Also:
        `API XFormatCondition <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFormatCondition.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XFormatCondition']

    @property
    def Enabled(self) -> bool:
        """
        specifies if the condition is enabled or not.
        """

    @property
    def Formula(self) -> str:
        """
        defines the formula of the format condition.
        
        If the formula evaluates to TRUE then the format will be applied.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
import typing
from .x_literal import XLiteral as XLiteral_79ec0969
from .x_node import XNode as XNode_5ee40822
if typing.TYPE_CHECKING:
    from .xuri import XURI as XURI_5682078c

class Literal(XLiteral_79ec0969, XNode_5ee40822):
    """
    Service Class

    represents a literal that may occur in a RDF graph.
    
    **since**
    
        OOo 3.0

    See Also:
        `API Literal <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1rdf_1_1Literal.html>`_
    """
    def create(self, Value: str) -> None:
        """
        creates a plain literal RDF node.
        """
    def createWithLanguage(self, Value: str, Language: str) -> None:
        """
        creates a literal RDF node with a language.
        """
    def createWithType(self, Value: str, Type: 'XURI_5682078c') -> None:
        """
        creates a typed literal RDF node.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form.runtime
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class FeatureState(object):
    """
    Struct Class

    encapsulates the state of a FormFeature
    
    **since**
    
        OOo 2.2

    See Also:
        `API FeatureState <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1form_1_1runtime_1_1FeatureState.html>`_
    """
    typeName: Literal['com.sun.star.form.runtime.FeatureState']

    def __init__(self, Enabled: typing.Optional[bool] = ..., State: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Enabled (bool, optional): Enabled value.
            State (object, optional): State value.
        """


    @property
    def Enabled(self) -> bool:
        """
        determines whether the respective feature is enabled (i.e.
        
        available) in the current state of the form.
        """


    @property
    def State(self) -> object:
        """
        determines the state of the feature.
        
        The concrete semantics depends on the concrete FormFeature.
        """


